@@ -142,9 +142,7 @@ class Amendment(Workflow, ModelSQL, ModelView):
                 for invoice_line in line.invoice_lines:
                     if invoice_line.invoice_state == 'draft':
                         invoice_lines.add(invoice_line)
-                for move in line.moves:
-                    if move.state == 'draft':
-                        moves.add(move)
+                moves.update(cls._stock_moves(line))
 
         InvoiceLine.delete(invoice_lines)
         Move.delete(moves)
@@ -152,6 +150,12 @@ class Amendment(Workflow, ModelSQL, ModelView):
         Invoice.update_taxes([i for i in invoices if i.lines])
         Invoice.delete([i for i in invoices if not i.lines])
 
+    @classmethod
+    def _stock_moves(cls, line):
+        for move in line.moves:
+            if move.state == 'draft':
+                yield move
+
 
 class AmendmentLine(ModelSQL, ModelView):
     "Purchase Amendment Line"
@@ -262,14 +266,13 @@ class AmendmentLine(ModelSQL, ModelView):
             },
         depends=['product', 'party', 'state', 'action'])
     quantity = fields.Float(
-        "Quantity",
-        digits=(16, Eval('unit_digits', 2)),
+        "Quantity", digits='unit',
         states={
             'readonly': Eval('state') != 'draft',
             'invisible': Eval('action') != 'line',
             'required': Eval('action') == 'line',
             },
-        depends=['unit_digits', 'action'])
+        depends=['action'])
     unit = fields.Many2One(
         'product.uom', "Unit", ondelete='RESTRICT',
         domain=[
@@ -297,9 +300,6 @@ class AmendmentLine(ModelSQL, ModelView):
             },
         depends=['state', 'action'])
 
-    unit_digits = fields.Function(
-        fields.Integer("Unit Digits"),
-        'on_change_with_unit_digits')
     product_uom_category = fields.Function(
         fields.Many2One('product.uom.category', "Product UoM Category"),
         'on_change_with_product_uom_category')
@@ -374,11 +374,6 @@ class AmendmentLine(ModelSQL, ModelView):
         if self.party:
             self.invoice_address = self.party.address_get(type='invoice')
 
-    @fields.depends('unit')
-    def on_change_with_unit_digits(self, name=None):
-        if self.unit:
-            return self.unit.digits
-
     @fields.depends('line')
     def on_change_with_product_uom_category(self, name=None):
         if self.line:
